# bitcoin_coin_selection

Port of Bitcoin core coin selection logic to Python <br>

# Installation

```pip install bitcoin_coin_selection```

# Context

Bitcoin core coin selection logic:<br>
https://github.com/bitcoin/bitcoin/blob/master/src/wallet/coinselection.cpp<br>
https://github.com/bitcoin/bitcoin/blob/master/src/wallet/wallet.cpp<br><br>

Erhardt's thesis on coin selection<br>
https://murch.one/wp-content/uploads/2016/11/erhardt2016coinselection.pdf<br><br>

Explanation of the "OutputGroup" type (privacy enhancement)<br>
https://github.com/bitcoin/bitcoin/pull/12257<br>
